@@ -40,7 +40,7 @@
 #include "udiskslinuxmanager.h"
 #include "udisksdaemon.h"
 #include "udisksdaemonutil.h"
-#include "udiskscleanup.h"
+#include "udisksstate.h"
 #include "udiskslinuxblockobject.h"
 #include "udiskslinuxdevice.h"
 
@@ -230,6 +230,8 @@ wait_for_loop_object (UDisksDaemon *daemon,
 
   /* First see if we have the right loop object */
   object = udisks_daemon_find_block_by_device_file (daemon, data->loop_device);
+  if (object == NULL)
+    goto out;
   block = udisks_object_peek_block (object);
   loop = udisks_object_peek_loop (object);
   if (block == NULL || loop == NULL)
@@ -417,11 +419,11 @@ handle_loop_setup (UDisksManager          *object,
     }
 
   /* update the loop file - need to do this before getting the uevent for the device  */
-  udisks_cleanup_add_loop (udisks_daemon_get_cleanup (manager->daemon),
-                           loop_device,
-                           path,
-                           fd_statbuf_valid ? fd_statbuf.st_dev : 0,
-                           caller_uid);
+  udisks_state_add_loop (udisks_daemon_get_state (manager->daemon),
+                         loop_device,
+                         path,
+                         fd_statbuf_valid ? fd_statbuf.st_dev : 0,
+                         caller_uid);
 
   memset (&li64, '\0', sizeof (li64));
   strncpy ((char *) li64.lo_file_name, path, LO_NAME_SIZE - 1);
@@ -503,6 +505,9 @@ wait_for_array_object (UDisksDaemon *daemon,
 
   /* First see if we have the right array object */
   object = udisks_daemon_find_block_by_device_file (daemon, raid_device_file);
+  if (object == NULL)
+    goto out;
+
   block = udisks_object_get_block (object);
   if (block == NULL)
     goto out;
@@ -533,7 +538,6 @@ handle_mdraid_create (UDisksManager         *_object,
 {
   UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (_object);
   UDisksObject *array_object = NULL;
-  WaitForArrayData wait_data;
   uid_t caller_uid;
   GError *error = NULL;
   const gchar *message;
@@ -773,8 +777,8 @@ handle_mdraid_create (UDisksManager         *_object,
   if (array_object == NULL)
     {
       g_prefix_error (&error,
-                      "Error waiting for array object after creating /dev/md%d",
-                      wait_data.md_num);
+                      "Error waiting for array object after creating %s",
+                      raid_device_file);
       g_dbus_method_invocation_take_error (invocation, error);
       goto out;
     }
@@ -800,9 +804,9 @@ handle_mdraid_create (UDisksManager         *_object,
   raid_device_num = statbuf.st_rdev;
 
   /* update the mdraid file */
-  udisks_cleanup_add_mdraid (udisks_daemon_get_cleanup (manager->daemon),
-                             raid_device_num,
-                             caller_uid);
+  udisks_state_add_mdraid (udisks_daemon_get_state (manager->daemon),
+                           raid_device_num,
+                           caller_uid);
 
   /* ... wipe the created RAID array */
   if (!udisks_daemon_launch_spawned_job_sync (manager->daemon,
